@@ -1,3 +1,4 @@
+#!/bin/bash
 #
 # Test the pop code
 #
@@ -19,6 +20,8 @@ f .git/patches/master/mode
 DONE
 }
 
+patches=4
+
 # the test itself
 empty_repo
 cd $REPODIR
@@ -53,6 +56,23 @@ do
 	guilt-push --all > /dev/null
 done
 
+guilt-pop --all > /dev/null
+
+for n in `seq -1 $patches`
+do
+	if [ $n -ge 0 ]; then
+		guilt-push -n $n > /dev/null
+	else
+		shouldfail guilt-push -n $n > /dev/null
+	fi
+
+	expected_files | verify_repo .git/patches
+
+	echo -n "[-n:$n] "
+
+	guilt-pop --all > /dev/null
+done
+
 # FIXME: make sure --all and multiple patch pop works
 
 complete_test
